/*
 *      Copyright (C) 2005-2013 Team XBMC
 *      http://xbmc.org
 *
 *  This Program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This Program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with XBMC; see the file COPYING.  If not, see
 *  <http://www.gnu.org/licenses/>.
 *
 */

#include "GUIWindowBlankOverlay.h"
#include "guilib/GUIFontManager.h"
#include "guilib/GUITextLayout.h"
#include "guilib/GUIWindowManager.h"
#include "utils/StringUtils.h"

#ifdef TARGET_POSIX
#include "linux/XMemUtils.h"
#endif

CGUIWindowBlankOverlay::CGUIWindowBlankOverlay(void)
  : CGUIDialog(WINDOW_BLANK_OVERLAY, "", DialogModalityType::MODELESS)
{
  m_needsScaling = false;
  m_layout = nullptr;
  m_renderOrder = RENDER_ORDER_WINDOW_DEBUG;
}

CGUIWindowBlankOverlay::~CGUIWindowBlankOverlay(void)
{
}

void CGUIWindowBlankOverlay::UpdateVisibility()
{
  if (g_windowManager.GetActiveWindowID() == WINDOW_SLIDESHOW) {
    Open();
  } else {
    Close();
  }
}

bool CGUIWindowBlankOverlay::OnMessage(CGUIMessage &message)
{
  if (message.GetMessage() == GUI_MSG_WINDOW_DEINIT)
  {
    delete m_layout;
    m_layout = nullptr;
  }
  return CGUIDialog::OnMessage(message);
}

void CGUIWindowBlankOverlay::Process(unsigned int currentTime, CDirtyRegionList &dirtyregions)
{
  g_graphicsContext.SetRenderingResolution(g_graphicsContext.GetResInfo(), false);

  if (!m_layout)
  {
    CGUIFont *font13 = g_fontManager.GetDefaultFont();
    CGUIFont *font13border = g_fontManager.GetDefaultFont(true);
    if (font13)
      m_layout = new CGUITextLayout(font13, true, 0, font13border);
  }
  if (!m_layout)
    return;

  std::string info;
  //info = StringUtils::Format("Window: %d", g_windowManager.GetActiveWindowID());
  info = StringUtils::Format(" ");

  float w, h;
  if (m_layout->Update(info))
    MarkDirtyRegion();
  m_layout->GetTextExtent(w, h);

  m_renderRegion.SetRect(0, 0, w, h);
}

void CGUIWindowBlankOverlay::Render()
{
  g_graphicsContext.SetRenderingResolution(g_graphicsContext.GetResInfo(), false);
  if (m_layout)
    m_layout->RenderOutline(m_renderRegion.x1, m_renderRegion.y1, 0xffffffff, 0xff000000, 0, 0);
}
